fix some Java 1.4 vs. 1.5 issues
diff --git a/releng.control/cc.sh b/releng.control/cc.sh
index 542c11f..30b5954 100644
--- a/releng.control/cc.sh
+++ b/releng.control/cc.sh
@@ -21,5 +21,8 @@
CCNAME="Webtools"
+# We want to execute CC itself in Java 5
+export JAVA_HOME=${JAVA_5_HOME}
+
sh $CCDIR/cruisecontrol.sh -configfile $BUILD_HOME/releng.control/cc_config.xml -jmxport $port -webport $webport -user $trivialUserName -password $trivialPw -cchome $CCDIR -ccname $CCNAME 1>out.txt 2>err.txt &
diff --git a/releng.control/commonComputedVariables.shsource b/releng.control/commonComputedVariables.shsource
index 4fd3912..b3a105d 100644
--- a/releng.control/commonComputedVariables.shsource
+++ b/releng.control/commonComputedVariables.shsource
@@ -21,20 +21,8 @@
# need for some PPC or Linux issues?
export JAVA_HIGH_ZIPFDS=500
-# for now, always use Java 5 as native "home", but
-# scripts and paths may still use java 1.4
-export JAVA_HOME=${JAVA_5_HOME}
-
-# values of the bootclasspath attribute used in ant javac calls.
-# the names of these jars are VM vendor specific. the first set
-# below, commented out, are typical for sun VM's. The
-# second set are for IBM's VM's ... which is what we use
-# on the PPC machine, so we'll leave that as the defaults
-# in this file.
-
-
-export bootclasspath="${JAVA_4_HOME}/jre/lib/core.jar:${JAVA_4_HOME}/jre/lib/ibmjsseprovider.jar:${JAVA_4_HOME}/jre/lib/xml.jar"
-export bootclasspath_15="${JAVA_5_HOME}/jre/lib/core.jar:${JAVA_5_HOME}/jre/lib/vm.jar:${JAVA_5_HOME}/jre/lib/xml.jar"
+# Spec java 1.4 as default vm to use
+export JAVA_HOME=${JAVA_4_HOME}
# OS specific support.
@@ -47,14 +35,23 @@
*ppc*) ibmjvm=true;;
esac
+
+# values of the bootclasspath attribute used in ant javac calls.
+# the names of these jars are VM vendor specific. the first set
+# below, commented out, are typical for sun VM's. The
+# second set are for IBM's VM's ... which is what we use
+# on the PPC machine, so we'll leave that as the defaults
+# in this file.
+
+
# set initial values as if for IBM's PPC VM
-export bootclasspath="${JAVA_4_HOME}/jre/lib/core.jar:${JAVA_4_HOME}/jre/lib/ibmjsseprovider.jar:${JAVA_4_HOME}/jre/lib/xml.jar"
+export bootclasspath="${JAVA_4_HOME}/jre/lib/core.jar:${JAVA_4_HOME}/jre/lib/xml.jar"
export bootclasspath_15="${JAVA_5_HOME}/jre/lib/core.jar:${JAVA_5_HOME}/jre/lib/vm.jar:${JAVA_5_HOME}/jre/lib/xml.jar"
export ANT_OPTS="-Xms128m -Xmx512m"
# and change them if Sun's VM is being used
if $sunjvm ; then
- export bootclasspath="${JAVA_4_HOME}/jre/lib/rt.jar:${JAVA_4_HOME}/jre/lib/jsse.jar"
+ export bootclasspath="${JAVA_4_HOME}/jre/lib/rt.jar"
export bootclasspath_15="${JAVA_5_HOME}/jre/lib/rt.jar"
export ANT_OPTS="-Xms128m -Xmx512m -XX:MaxPermSize=128M -XX:+UseParallelGC"
fi
diff --git a/releng.control/ant.sh b/releng.control/ant.sh
index 6dd6709..d7f1e46 100644
--- a/releng.control/ant.sh
+++ b/releng.control/ant.sh
@@ -1,18 +1,24 @@
-#!/bin/sh
-
-# remember to leave no slashes on commonVariations in source command,
-# so that users path is used to find it (first). But, path on
-# commonComputedVariables means we expect to execute only our
-# version
-
-if [ -n $BUILD_INITIALIZED ]
-then
- source commonVariations.shsource
- source ${BUILD_HOME}/releng.control/commonComputedVariables.shsource
-fi
-
-
-ANT_CMD=${ANT_HOME}/bin/ant
-
-exec "$ANT_CMD" "$@"
-
+#!/bin/sh
+
+# remember to leave no slashes on commonVariations in source command,
+# so that users path is used to find it (first). But, path on
+# commonComputedVariables means we expect to execute only our
+# version
+
+if [ -n $BUILD_INITIALIZED ]
+then
+ source commonVariations.shsource
+ source ${BUILD_HOME}/releng.control/commonComputedVariables.shsource
+fi
+
+# For most ant tasks, we want Java 4 to be default,
+# so if not desired (such as for WTP 2.0 unit tests),
+# then we have to spec Java 5 right there where we run
+# the tests.
+export JAVA_HOME=${JAVA_4_HOME}
+
+
+ANT_CMD=${ANT_HOME}/bin/ant
+
+exec "$ANT_CMD" "$@"
+